@@ -219,7 +219,7 @@ class KoboForm:
                 and field["type"] != "end_repeat"
             ):
 
-                name_q = field["name"]
+                name_q = field["$autoname"]
                 if "label" in field:
                     label_q = field["label"][0]
                 else:
@@ -331,12 +331,14 @@ class KoboForm:
         self.__content = res.json()["content"]
 
     def _extract_from_asset(self, asset: dict) -> None:
+        self.metadata["uid"] = asset["uid"]
         self.metadata["name"] = asset["name"]
         self.metadata["owner"] = asset["owner__username"]
         self.metadata["date_created"] = asset["date_created"]
         self.metadata["date_modified"] = asset["date_modified"]
         self.metadata["version_id"] = asset["version_id"]
         self.metadata["has_deployment"] = asset["has_deployment"]
+        self.metadata["num_submissions"] = asset["deployment__submission_count"]
         self.metadata["geo"] = asset["summary"]["geo"]
 
         self.url_asset = asset["url"]
